==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.md <==
# AwsIoTGreengrassProtocol


```text
aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol
```

```text
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')
```



| Illustration | AwsIoTGreengrassProtocol | AwsIoTGreengrassProtocolCard | AwsIoTGreengrassProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.png) | ![illustration for AwsIoTGreengrassProtocol](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.Local.png) | ![illustration for AwsIoTGreengrassProtocolCard](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocolCard.Local.png) | ![illustration for AwsIoTGreengrassProtocolGroup](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocolGroup.Local.png) |




## AwsIoTGreengrassProtocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocol
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocol('AwsIoTGreengrassProtocol', 'Aws Io T Greengrass Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocol
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocol('AwsIoTGreengrassProtocol', 'Aws Io T Greengrass Protocol', 'an optional tech label')
@enduml
```

## AwsIoTGreengrassProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolCard('AwsIoTGreengrassProtocolCard', 'Aws Io T Greengrass Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolCard('AwsIoTGreengrassProtocolCard', 'Aws Io T Greengrass Protocol Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolGroup('AwsIoTGreengrassProtocolGroup', 'Aws Io T Greengrass Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolGroup('AwsIoTGreengrassProtocolGroup', 'Aws Io T Greengrass Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.md <==
# AwsIoTGreengrassProtocol


```text
aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol
```

```text
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')
```



| Illustration | AwsIoTGreengrassProtocol | AwsIoTGreengrassProtocolCard | AwsIoTGreengrassProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.png) | ![illustration for AwsIoTGreengrassProtocol](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol.Local.png) | ![illustration for AwsIoTGreengrassProtocolCard](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocolCard.Local.png) | ![illustration for AwsIoTGreengrassProtocolGroup](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassProtocolGroup.Local.png) |




## AwsIoTGreengrassProtocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocol
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocol('AwsIoTGreengrassProtocol', 'Aws Io T Greengrass Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocol
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocol('AwsIoTGreengrassProtocol', 'Aws Io T Greengrass Protocol', 'an optional tech label')
@enduml
```

## AwsIoTGreengrassProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolCard('AwsIoTGreengrassProtocolCard', 'Aws Io T Greengrass Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolCard('AwsIoTGreengrassProtocolCard', 'Aws Io T Greengrass Protocol Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolGroup('AwsIoTGreengrassProtocolGroup', 'Aws Io T Greengrass Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassProtocol')

' renders the element
AwsIoTGreengrassProtocolGroup('AwsIoTGreengrassProtocolGroup', 'Aws Io T Greengrass Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
